/*
 * Copyright 2016 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.processing.engine.handling.impl;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import org.kie.workbench.common.forms.processing.engine.handling.FieldChangeHandler;
import org.kie.workbench.common.forms.processing.engine.handling.FormField;

public class FieldChangeProcessor {

    private FormField formField;

    private List<FieldChangeHandler> changeHandlers = new ArrayList<>();

    public FieldChangeProcessor(FormField formField) {

        if(formField == null) {
            throw new IllegalArgumentException("FormField cannot be null");
        }

        this.formField = formField;
    }

    public void addFieldChangeHandler(FieldChangeHandler handler) {
        assert handler != null;

        changeHandlers.add(handler);
    }

    public String getFieldName() {
        return formField.getFieldName();
    }

    public boolean isRequiresValidation() {
        return formField.isValidateOnChange();
    }

    public Collection<FieldChangeHandler> getChangeHandlers() {
        return Collections.unmodifiableCollection(changeHandlers);
    }

    public FormField getField() {
        return formField;
    }
}
